==> cforge-7.x-1.0-rc14-core.tar.gz: cforge-7.x-1.0-rc14/profiles/cforge/themes/sky_seldulac/template.php <==
<?php


/**
 * Override theme_menu_local_task().
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs.
 *
 * @ingroup themeable
 */
function sky_seldulac_menu_local_tasks() {
  $primary = menu_primary_local_tasks();
  $secondary = menu_secondary_local_tasks();
  $output = '';
  if ($primary || $secondary) {
    if ($primary) {
      $output .= "\n".'<div class="tabs-primary">'."\n".
      '  <ul>'."\n". render($primary) .'</ul>'."\n".
      '</div>';
    }
    if ($secondary) {
      $output .= "\n".'<div class="tabs-secondary">'."\n" .
      '  <ul>'."\n". render($secondary) .'</ul>'."\n" .
      '</div>';
    }
    return '<div class="tab-wrapper">' . $output .'</div>';
  }
}

/**
* @param array $variables
* @return string
*/
function sky_seldulac_menu_local_action($variables) {
  $link = $variables['element']['#link'];
  $output = '<li>';
  $options = array('attributes' => array('title' => @$link['description']));
  if (isset($link['localized_options'])) {
    $options += $link['localized_options'];
  }

  if (isset($link['href'])) {
    $output .= l($link['title'], $link['href'], $options);
  }
  elseif (!empty($link['localized_options']['html'])) {
    $output .= $link['title'];
  }
  else {
    $output .= check_plain($link['title']);
  }
  $output .= "</li>\n";
  return $output;
}

function sky_seldulac_feed_icon($variables) {
  if ($image = theme('image', array('path' => 'misc/feed.png', 'width' => 16, 'height' => 16))) {
    return l(
      $image,
      $variables['url'],
      array(
        'html' => TRUE,
        'attributes' => array(
          'class' => array('feed-icon'),
          'title' => t('Get !feed-title delivered as it happens!', array('!feed-title' => $variables['title']))
        )
      )
    );
  }
}
//prevent the teasers from breaking off between tags by converting teasers to plain text
function sky_seldulac_preprocess_node(&$vars, $hook) {
  // Strip tags from teaser
  if ($vars['teaser']) {
    // $coreteaser is the teaser without extra cck fields
    $items = field_get_items('node', $vars['node'], 'body');
    if ($items && is_array($items) && count($items)) {
      $body = drupal_render(field_view_value('node', $vars['node'], 'body', current($items)));
      // Replace corresponding part of $teaser with stripped $coreteaser
      $vars['content'] = substr(strip_tags($body, '<img>'), 0, 400);
    }
  }
}

==> cforge-7.x-1.2-core.tar.gz: cforge-7.x-1.2/profiles/cforge/themes/sky_seldulac/template.php <==
<?php


/**
 * Override theme_menu_local_task().
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs.
 *
 * @ingroup themeable
 */
function sky_seldulac_menu_local_tasks() {
  $primary = menu_primary_local_tasks();
  $secondary = menu_secondary_local_tasks();
  $output = '';
  if ($primary || $secondary) {
    if ($primary) {
      $output .= "\n".'<div class="tabs-primary">'."\n".
      '  <ul>'."\n". render($primary) .'</ul>'."\n".
      '</div>';
    }
    if ($secondary) {
      $output .= "\n".'<div class="tabs-secondary">'."\n" .
      '  <ul>'."\n". render($secondary) .'</ul>'."\n" .
      '</div>';
    }
    return '<div class="tab-wrapper">' . $output .'</div>';
  }
}

/**
* @param array $variables
* @return string
*/
function sky_seldulac_menu_local_action($variables) {
  $link = $variables['element']['#link'];
  $output = '<li>';
  $options = array('attributes' => array('title' => @$link['description']));
  if (isset($link['localized_options'])) {
    $options += $link['localized_options'];
  }

  if (isset($link['href'])) {
    $output .= l($link['title'], $link['href'], $options);
  }
  elseif (!empty($link['localized_options']['html'])) {
    $output .= $link['title'];
  }
  else {
    $output .= check_plain($link['title']);
  }
  $output .= "</li>\n";
  return $output;
}

function sky_seldulac_feed_icon($variables) {
  if ($image = theme('image', array('path' => 'misc/feed.png', 'width' => 16, 'height' => 16))) {
    return l(
      $image,
      $variables['url'],
      array(
        'html' => TRUE,
        'attributes' => array(
          'class' => array('feed-icon'),
          'title' => t('Get !feed-title delivered as it happens!', array('!feed-title' => $variables['title']))
        )
      )
    );
  }
}


/**
 * Theme the calendar title
 */
function sky_seldulac_date_nav_title($params) {
  $view = $params['view'];
  $date_info = $view->date_info;
  $link = !empty($params['link']) ? $params['link'] : FALSE;
  $title = date_format_date($date_info->min_date, 'custom', 'F Y');
      
  if (!empty($date_info->mini) || $link) {
    // Month navigation titles are used as links in the mini view.
    $attributes = array('title' => t('View full page month'));
    $url = date_pager_url($view, $granularity, $date_info->year . '-' . date_pad($date_info->month), TRUE);
    return l($title, $url, array('attributes' => $attributes));
  }
  else {
    return $title;
  }
}

function sky_seldulac_form_comment_form_alter(&$form, &$form_state) {   
  $form['comment_body']['und']['0']['#title'] = t('Comment');
}
